Rutherford
==========

Atom feed extension for Tinkerer.

Usage
-----

Add 'rutherford' to your list of extensions and 

.. code-block:: python

    blog_date = '2013'
    rights = "This work is licensed under a Creative Commons Attribution 3.0 United States License: http://creativecommons.org/licenses/by/3.0/us/"

to your config. Then "tinker --build" and look for the feed.atom file in your
output directory.
